Contributing
============

Patches and suggestions are strongly encouraged! GitHub pull requests are
preferred, but other mechanisms of feedback are welcome.

``pyramid_uniform`` has a comprehensive test suite with 100% line and branch
coverage, as reported by the excellent ``coverage`` module. To run the tests,
simply run in the top level of the repo::

    $ tox

This will also ensure that the Sphinx documentation builds correctly, and that
there are no `PEP8 <http://www.python.org/dev/peps/pep-0008/>`_ or `Pyflakes
<http://pypi.python.org/pypi/pyflakes>`_ warnings in the codebase.

Any pull requests should preserve all of these things.
